@@ -23,6 +23,7 @@ from __future__ import annotations
 import asyncio
 from logging import Logger
 import os
+import sys
 import re
 from abc import ABC
 from collections import OrderedDict
@@ -39,8 +40,11 @@ from typing import (
     Dict,
     Union,
     Any,
-    cast, Tuple
+    cast, Tuple,
+    Callable,
+    Coroutine
 )
+import signal
 
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from apscheduler.triggers.cron import CronTrigger
@@ -58,6 +62,8 @@ from wechaty_puppet import (
     ScanStatus
 )
 
+from .config import config
+
 from .exceptions import (
     WechatyPluginError,
 )
@@ -142,6 +148,32 @@ def _list_routes_txt(app: Quart) -> List[str]:
     return routes_txt
 
 
+async def get_shutdown_trigger() -> Callable[[], Coroutine[Any, Any, Any]]:
+    """register the system shutdown trigger event"""
+    signal_event = asyncio.Event()
+    loop = asyncio.get_event_loop()
+
+    def _signal_handler(*_: Any) -> None:  # noqa: N803
+        print('receive signal event ...')
+        signal_event.set()
+
+    for signal_name in ["SIGINT", "SIGTERM", "SIGBREAK"]:
+        if hasattr(signal, signal_name):
+            try:
+                loop.add_signal_handler(getattr(signal, signal_name), _signal_handler)
+            except NotImplementedError:
+                # Add signal handler may not be implemented on Windows
+                signal.signal(getattr(signal, signal_name), _signal_handler)
+
+    return signal_event.wait
+
+
+async def shutdown(trigger: Callable[[], Coroutine[Any, Any, Any]]) -> None:
+    """when trigger the shutdown, it will call sys.exit"""
+    await trigger()
+    sys.exit(0)
+
+
 @dataclass
 class WechatyPluginOptions:
     """options for wechaty plugin"""
@@ -152,7 +184,7 @@ class WechatyPluginOptions:
 @dataclass
 class WechatySchedulerOptions:
     """options for wechaty scheduler"""
-    job_store: Union[str, SQLAlchemyJobStore] = 'sqlite:///.wechaty/job.db'
+    job_store: Union[str, SQLAlchemyJobStore] = f'sqlite:///{config.cache_dir}/job.db'
     job_store_alias: str = 'wechaty-scheduler'
 
 
@@ -168,7 +200,7 @@ class WechatySchedulerMixin:
     _scheduler_field: str = "_scheduler"
 
     scheduler_job_alias: str = 'wechaty_scheduler'
-    scheduler_db_file: str = '.wechaty/job.db'
+    scheduler_db_file: str = f'{config.cache_dir}/job.db'
 
     @property
     def scheduler(self) -> AsyncIOScheduler:
@@ -363,6 +395,7 @@ class WechatyPlugin(ABC, WechatySchedulerMixin, WechatyEventMixin):
             options = WechatyPluginOptions()
         self.options = options
         self._default_logger: Optional[Logger] = None
+        self._cache_dir: Optional[str] = None
 
     def set_bot(self, bot: Wechaty) -> None:
         """set bot instance to WechatyPlugin
@@ -398,10 +431,25 @@ class WechatyPlugin(ABC, WechatySchedulerMixin, WechatyEventMixin):
 
         this is friendly for code typing
         """
-        _cache_dir = os.path.join('.wechaty', self.name)
+        _cache_dir = os.path.join(config.cache_dir, self.name)
         os.makedirs(_cache_dir, exist_ok=True)
         return _cache_dir
 
+    @cache_dir.setter
+    def cache_dir(self, value: str) -> None:
+        """set the cache dir although there is already set
+
+        Args:
+            value (str): the new cache dir
+        """
+        if not self._cache_dir:
+            self.logger.warning(
+                'there is already cache_dir<%s>', self._cache_dir
+            )
+
+        os.makedirs(value, exist_ok=True)
+        self._cache_dir = value
+
     @property
     def logger(self) -> Logger:
         """get the default logger of plugin which will automaticly
@@ -466,7 +514,7 @@ def _load_default_plugins() -> List[WechatyPlugin]:
     # TODO: to be implemented
 
 
-class WechatyPluginManager:     # pylint: disable=too-many-instance-attributes
+class WechatyPluginManager(WechatyEventMixin, WechatySchedulerMixin):     # pylint: disable=too-many-instance-attributes
     """manage the wechaty plugin, It will support some features."""
 
     def __init__(
@@ -638,18 +686,19 @@ class WechatyPluginManager:     # pylint: disable=too-many-instance-attributes
         log.info('============================starting web service========================')
         log.info('starting web service at endpoint: <{%s}:{%d}>', host, port)
 
-        # shutdown_trigger = await get_shutdown_trigger()
+        shutdown_trigger = await get_shutdown_trigger()
         task = self.app.run_task(
             host=host,
             port=port,
             use_reloader=False,
-            # shutdown_trigger=shutdown_trigger
+            shutdown_trigger=shutdown_trigger
         )
         loop = asyncio.get_event_loop()
         loop.create_task(task)
-        # loop.create_task(
-        #     shutdown(shutdown_trigger)
-        # )
+
+        loop.create_task(
+            shutdown(shutdown_trigger)
+        )
 
         for route_txt in routes_txt:
             log.info(route_txt)
