@@ -137,7 +137,7 @@ class Room(Accessory[RoomPayload]):
                 payload = room.payload
                 if not payload:
                     return False
-                if query == payload.id or query in payload.topic:
+                if query == payload.id or (query.lower() in payload.topic.lower()): # type: ignore
                     return True
                 return False
             func = filter_func
@@ -149,7 +149,7 @@ class Room(Accessory[RoomPayload]):
                 if not payload:
                     return False
 
-                if query.id == payload.id or query.topic in payload.topic:
+                if query.id == payload.id or (query.topic.lower() in payload.topic.lower()): # noqa
                     return True
                 return False
             func = filter_func
@@ -329,9 +329,8 @@ class Room(Accessory[RoomPayload]):
                 for mention_id in mention_ids:
                     mention_contact: Contact = self.wechaty.Contact.load(mention_id)
                     await mention_contact.ready()
-                    alias = await mention_contact.alias()
                     name = mention_contact.name
-                    mention_info.append('@' + (alias or name))
+                    mention_info.append('@' + name)
 
                 mention_text = AT_SEPARATOR.join(mention_info)
                 some_thing = mention_text + ' ' + some_thing
